@@ -57,6 +57,29 @@ from gopup.event.area_baidu import (
     migration_scale_baidu
 )
 
+"""
+历史上的今日接口
+"""
+from gopup.event.history_daily import history_daily
+
+
+"""
+榜单接口
+"""
+from gopup.event.hot_list import (
+    douban_movie_list,
+    douban_week_praise_list,
+    zhihu_hot_search_list,
+    zhihu_hot_list,
+    wx_hot_word_list,
+    wx_hot_list,
+    weibo_hot_search_list,
+    weibo_new_era_list,
+    baidu_hot_list,
+    baidu_today_hot_list,
+    baidu_hot_word_list
+)
+
 
 """
 新型冠状病毒接口
@@ -144,6 +167,15 @@ from gopup.life.university import (
     adult_university
 )
 
+"""
+火车数据
+"""
+from gopup.life.train import (
+    station_name,
+    train_time_table
+)
+
+
 """
 微博运营数据
 """
@@ -152,6 +184,14 @@ from gopup.mcn.weibo import (
     weibo_list
 )
 
+"""
+中国电竞价值排行榜
+"""
+from gopup.life.game import (
+    player_rank,
+    club_rank
+)
+
 
 """
 专业版接口
